@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Default library paths for the programming examples
-%  Last updated on February 24, 2023
+%  Last updated on March 9, 2023
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2023 Paulo Moura <pmoura@logtalk.org>
@@ -139,6 +139,7 @@ logtalk_library_path(my_types, examples('my_types/')).
 logtalk_library_path(named_databases, examples('named_databases/')).
 logtalk_library_path(ncl, examples('ncl/')).
 logtalk_library_path(nondet, threads('nondet/')).
+logtalk_library_path(neo4j, examples('neo4j/')).
 logtalk_library_path(now_you_see_me, examples('now_you_see_me/')).
 logtalk_library_path(object_aliases, examples('object_aliases/')).
 logtalk_library_path(operators, examples('operators/')).
